You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by st...@apache.org on 2012/09/20 22:50:40 UTC

svn commit: r1388211 - in /subversion/branches/10Gb/subversion: include/svn_fs.h libsvn_fs/fs-loader.c libsvn_fs/fs-loader.h libsvn_fs_fs/dag.c libsvn_fs_fs/dag.h libsvn_fs_fs/fs_fs.c libsvn_fs_fs/fs_fs.h libsvn_fs_fs/tree.c libsvn_repos/reporter.c

Author: stefan2
Date: Thu Sep 20 20:50:39 2012
New Revision: 1388211

URL: http://svn.apache.org/viewvc?rev=1388211&view=rev
Log:
On the 10Gb branch: rename *try_process_file_content to
*try_process_file_contents and update callers.

* subversion/include/svn_fs.h
  (svn_fs_process_content_func_t,
   svn_fs_try_process_file_contents): rename

* subversion/libsvn_fs_fs/dag.h
  (svn_fs_fs__dag_try_process_file_contents): rename
* subversion/libsvn_fs_fs/dag.c
  (svn_fs_fs__dag_try_process_file_contents): rename, update

* subversion/libsvn_fs_fs/fs_fs.c
  (cache_access_wrapper_baton_t): update
  (svn_fs_fs__try_process_file_contents): rename
* subversion/libsvn_fs_fs/fs_fs.h
  (svn_fs_fs__try_process_file_contents): rename

* subversion/libsvn_fs/fs-loader.c
  (svn_fs_try_process_file_contents): rename, update
* subversion/libsvn_fs/fs-loader.h
  (root_vtable_t): update

* subversion/libsvn_fs_fs/tree.c
  (fs_try_process_file_contents): rename, update
  (root_vtable): update

* subversion/libsvn_repos/reporter.c
  (delta_files): update

Modified:
    subversion/branches/10Gb/subversion/include/svn_fs.h
    subversion/branches/10Gb/subversion/libsvn_fs/fs-loader.c
    subversion/branches/10Gb/subversion/libsvn_fs/fs-loader.h
    subversion/branches/10Gb/subversion/libsvn_fs_fs/dag.c
    subversion/branches/10Gb/subversion/libsvn_fs_fs/dag.h
    subversion/branches/10Gb/subversion/libsvn_fs_fs/fs_fs.c
    subversion/branches/10Gb/subversion/libsvn_fs_fs/fs_fs.h
    subversion/branches/10Gb/subversion/libsvn_fs_fs/tree.c
    subversion/branches/10Gb/subversion/libsvn_repos/reporter.c

Modified: subversion/branches/10Gb/subversion/include/svn_fs.h
URL: http://svn.apache.org/viewvc/subversion/branches/10Gb/subversion/include/svn_fs.h?rev=1388211&r1=1388210&r2=1388211&view=diff
==============================================================================
--- subversion/branches/10Gb/subversion/libsvn_fs/fs-loader.c (original)
+++ subversion/branches/10Gb/subversion/libsvn_fs/fs-loader.c Thu Sep 20 20:50:39 2012
@@ -1204,21 +1204,21 @@ svn_fs_file_contents(svn_stream_t **cont
 }
 
 svn_error_t *
-svn_fs_try_process_file_content(svn_boolean_t *success,
-                                svn_fs_root_t *root,
-                                const char *path,
-                                svn_fs_process_content_func_t processor,
-                                void* baton,
-                                apr_pool_t *pool)
+svn_fs_try_process_file_contents(svn_boolean_t *success,
+                                 svn_fs_root_t *root,
+                                 const char *path,
+                                 svn_fs_process_contents_func_t processor,
+                                 void* baton,
+                                 apr_pool_t *pool)
 {
   /* if the FS doesn't implement this function, report a "failed" attempt */
-  if (root->vtable->try_process_file_content == NULL)
+  if (root->vtable->try_process_file_contents == NULL)
     {
       *success = FALSE;
       return SVN_NO_ERROR;
     }
 
-  return svn_error_trace(root->vtable->try_process_file_content(
+  return svn_error_trace(root->vtable->try_process_file_contents(
                          success,
                          root, path,
                          processor, baton, pool));

Modified: subversion/branches/10Gb/subversion/libsvn_fs/fs-loader.h
URL: http://svn.apache.org/viewvc/subversion/branches/10Gb/subversion/libsvn_fs/fs-loader.h?rev=1388211&r1=1388210&r2=1388211&view=diff
==============================================================================
--- subversion/branches/10Gb/subversion/libsvn_fs/fs-loader.h (original)
+++ subversion/branches/10Gb/subversion/libsvn_fs/fs-loader.h Thu Sep 20 20:50:39 2012
@@ -306,12 +306,12 @@ typedef struct root_vtable_t
   svn_error_t *(*file_contents)(svn_stream_t **contents,
                                 svn_fs_root_t *root, const char *path,
                                 apr_pool_t *pool);
-  svn_error_t *(*try_process_file_content)(svn_boolean_t *success,
-                                           svn_fs_root_t *target_root,
-                                           const char *target_path,
-                                           svn_fs_process_content_func_t processor,
-                                           void* baton,
-                                           apr_pool_t *pool);
+  svn_error_t *(*try_process_file_contents)(svn_boolean_t *success,
+                                            svn_fs_root_t *target_root,
+                                            const char *target_path,
+                                            svn_fs_process_contents_func_t processor,
+                                            void* baton,
+                                            apr_pool_t *pool);
   svn_error_t *(*make_file)(svn_fs_root_t *root, const char *path,
                             apr_pool_t *pool);
   svn_error_t *(*apply_textdelta)(svn_txdelta_window_handler_t *contents_p,

Modified: subversion/branches/10Gb/subversion/libsvn_fs_fs/dag.c
URL: http://svn.apache.org/viewvc/subversion/branches/10Gb/subversion/libsvn_fs_fs/dag.c?rev=1388211&r1=1388210&r2=1388211&view=diff
==============================================================================
--- subversion/branches/10Gb/subversion/libsvn_fs_fs/dag.c (original)
+++ subversion/branches/10Gb/subversion/libsvn_fs_fs/dag.c Thu Sep 20 20:50:39 2012
@@ -947,20 +947,20 @@ svn_fs_fs__dag_get_file_delta_stream(svn
 
 
 svn_error_t *
-svn_fs_fs__dag_try_process_file_content(svn_boolean_t *success,
-                                        dag_node_t *node,
-                                        svn_fs_process_content_func_t processor,
-                                        void* baton,
-                                        apr_pool_t *pool)
+svn_fs_fs__dag_try_process_file_contents(svn_boolean_t *success,
+                                         dag_node_t *node,
+                                         svn_fs_process_contents_func_t processor,
+                                         void* baton,
+                                         apr_pool_t *pool)
 {
   node_revision_t *noderev;
 
   /* Go get fresh node-revisions for the nodes. */
   SVN_ERR(get_node_revision(&noderev, node));
 
-  return svn_fs_fs__try_process_file_content(success, node->fs,
-                                             noderev,
-                                             processor, baton, pool);
+  return svn_fs_fs__try_process_file_contents(success, node->fs,
+                                              noderev,
+                                              processor, baton, pool);
 }
 
 

Modified: subversion/branches/10Gb/subversion/libsvn_fs_fs/dag.h
URL: http://svn.apache.org/viewvc/subversion/branches/10Gb/subversion/libsvn_fs_fs/dag.h?rev=1388211&r1=1388210&r2=1388211&view=diff
==============================================================================
--- subversion/branches/10Gb/subversion/libsvn_fs_fs/dag.h (original)
+++ subversion/branches/10Gb/subversion/libsvn_fs_fs/dag.h Thu Sep 20 20:50:39 2012
@@ -410,11 +410,11 @@ svn_error_t *svn_fs_fs__dag_get_contents
    Use POOL for all allocations.
  */
 svn_error_t *
-svn_fs_fs__dag_try_process_file_content(svn_boolean_t *success,
-                                        dag_node_t *node,
-                                        svn_fs_process_content_func_t processor,
-                                        void* baton,
-                                        apr_pool_t *pool);
+svn_fs_fs__dag_try_process_file_contents(svn_boolean_t *success,
+                                         dag_node_t *node,
+                                         svn_fs_process_contents_func_t processor,
+                                         void* baton,
+                                         apr_pool_t *pool);
 
 
 /* Set *STREAM_P to a delta stream that will turn the contents of SOURCE into

Modified: subversion/branches/10Gb/subversion/libsvn_fs_fs/fs_fs.c
URL: http://svn.apache.org/viewvc/subversion/branches/10Gb/subversion/libsvn_fs_fs/fs_fs.c?rev=1388211&r1=1388210&r2=1388211&view=diff
==============================================================================
--- subversion/branches/10Gb/subversion/libsvn_fs_fs/fs_fs.h (original)
+++ subversion/branches/10Gb/subversion/libsvn_fs_fs/fs_fs.h Thu Sep 20 20:50:39 2012
@@ -157,12 +157,12 @@ svn_error_t *svn_fs_fs__get_contents(svn
    Use POOL for all allocations.
  */
 svn_error_t *
-svn_fs_fs__try_process_file_content(svn_boolean_t *success,
-                                    svn_fs_t *fs,
-                                    node_revision_t *noderev,
-                                    svn_fs_process_content_func_t processor,
-                                    void* baton,
-                                    apr_pool_t *pool);
+svn_fs_fs__try_process_file_contents(svn_boolean_t *success,
+                                     svn_fs_t *fs,
+                                     node_revision_t *noderev,
+                                     svn_fs_process_contents_func_t processor,
+                                     void* baton,
+                                     apr_pool_t *pool);
 
 /* Set *STREAM_P to a delta stream turning the contents of the file SOURCE into
    the contents of the file TARGET, allocated in POOL.

Modified: subversion/branches/10Gb/subversion/libsvn_fs_fs/tree.c
URL: http://svn.apache.org/viewvc/subversion/branches/10Gb/subversion/libsvn_fs_fs/tree.c?rev=1388211&r1=1388210&r2=1388211&view=diff
==============================================================================
--- subversion/branches/10Gb/subversion/include/svn_fs.h (original)
+++ subversion/branches/10Gb/subversion/include/svn_fs.h Thu Sep 20 20:50:39 2012
@@ -1977,7 +1977,7 @@ svn_fs_file_contents(svn_stream_t **cont
 
 /**
  * Callback function type that gets presented with a immutable non-NULL
  * @a content of @a len bytes.  Further parameters may be passed through
  * in @a baton.
  *
  * Allocations must be made in @a pool.
@@ -1985,10 +1985,10 @@ svn_fs_file_contents(svn_stream_t **cont
  * @since New in 1.9
  */
 typedef svn_error_t *
-(*svn_fs_process_content_func_t)(const unsigned char *content,
-                                 apr_size_t len,
-                                 void *baton,
-                                 apr_pool_t *pool);
+(*svn_fs_process_contents_func_t)(const unsigned char *contents,
+                                  apr_size_t len,
+                                  void *baton,
+                                  apr_pool_t *pool);
 
 /** Attempts to efficiently provide the contents of the file @a path in
  * @a root.  If that succeeds, @a *success will be set to #TRUE and the
@@ -2007,12 +2007,12 @@ typedef svn_error_t *
  * @since New in 1.9
  */
 svn_error_t *
-svn_fs_try_process_file_content(svn_boolean_t *success,
-                                svn_fs_root_t *root,
-                                const char *path,
-                                svn_fs_process_content_func_t processor,
-                                void* baton,
-                                apr_pool_t *pool);
+svn_fs_try_process_file_contents(svn_boolean_t *success,
+                                 svn_fs_root_t *root,
+                                 const char *path,
+                                 svn_fs_process_contents_func_t processor,
+                                 void* baton,
+                                 apr_pool_t *pool);
 
 /** Create a new file named @a path in @a root.  The file's initial contents
  * are the empty string, and it has no properties.  @a root must be the
@@ -1977,7 +1977,7 @@ svn_fs_file_contents(svn_stream_t **cont
 /**
  * Callback function type that gets presented with a immutable non-NULL
- * @a content of @a len bytes.  Further parameters may be passed through
+ * @a contents of @a len bytes.  Further parameters may be passed through
  * in @a baton.
  *

Modified: subversion/branches/10Gb/subversion/libsvn_fs/fs-loader.c
URL: http://svn.apache.org/viewvc/subversion/branches/10Gb/subversion/libsvn_fs/fs-loader.c?rev=1388211&r1=1388210&r2=1388211&view=diff
==============================================================================
--- subversion/branches/10Gb/subversion/libsvn_fs_fs/fs_fs.c (original)
+++ subversion/branches/10Gb/subversion/libsvn_fs_fs/fs_fs.c Thu Sep 20 20:50:39 2012
@@ -5100,11 +5100,11 @@ svn_fs_fs__get_file_delta_stream(svn_txd
  */
 typedef struct cache_access_wrapper_baton_t
 {
-  svn_fs_process_content_func_t func;
+  svn_fs_process_contents_func_t func;
   void* baton;
 } cache_access_wrapper_baton_t;
 
 /* Wrapper to translate between svn_fs_process_content_func_t and
  * svn_cache__partial_getter_func_t.
  */
 static svn_error_t *
@@ -5128,12 +5128,12 @@ cache_access_wrapper(void **out,
 }
 
 svn_error_t *
-svn_fs_fs__try_process_file_content(svn_boolean_t *success,
-                                    svn_fs_t *fs,
-                                    node_revision_t *noderev,
-                                    svn_fs_process_content_func_t processor,
-                                    void* baton,
-                                    apr_pool_t *pool)
+svn_fs_fs__try_process_file_contents(svn_boolean_t *success,
+                                     svn_fs_t *fs,
+                                     node_revision_t *noderev,
+                                     svn_fs_process_contents_func_t processor,
+                                     void* baton,
+                                     apr_pool_t *pool)
 {
   representation_t *rep = noderev->data_rep;
   if (rep)
@@ -5100,11 +5100,11 @@ svn_fs_fs__get_file_delta_stream(svn_txd
 } cache_access_wrapper_baton_t;
 
-/* Wrapper to translate between svn_fs_process_content_func_t and
+/* Wrapper to translate between svn_fs_process_contents_func_t and
  * svn_cache__partial_getter_func_t.
  */

Modified: subversion/branches/10Gb/subversion/libsvn_fs_fs/fs_fs.h
URL: http://svn.apache.org/viewvc/subversion/branches/10Gb/subversion/libsvn_fs_fs/fs_fs.h?rev=1388211&r1=1388210&r2=1388211&view=diff
==============================================================================
--- subversion/branches/10Gb/subversion/libsvn_fs_fs/tree.c (original)
+++ subversion/branches/10Gb/subversion/libsvn_fs_fs/tree.c Thu Sep 20 20:50:39 2012
@@ -2261,24 +2261,24 @@ fs_file_contents(svn_stream_t **contents
 /* --- End machinery for svn_fs_file_contents() ---  */
 
 
-/* --- Machinery for svn_fs_try_process_file_content() ---  */
+/* --- Machinery for svn_fs_try_process_file_contents() ---  */
 
 static svn_error_t *
-fs_try_process_file_content(svn_boolean_t *success,
-                            svn_fs_root_t *root,
-                            const char *path,
-                            svn_fs_process_content_func_t processor,
-                            void* baton,
-                            apr_pool_t *pool)
+fs_try_process_file_contents(svn_boolean_t *success,
+                             svn_fs_root_t *root,
+                             const char *path,
+                             svn_fs_process_contents_func_t processor,
+                             void* baton,
+                             apr_pool_t *pool)
 {
   dag_node_t *node;
   SVN_ERR(get_dag(&node, root, path, pool));
 
-  return svn_fs_fs__dag_try_process_file_content(success, node,
-                                                 processor, baton, pool);
+  return svn_fs_fs__dag_try_process_file_contents(success, node,
+                                                  processor, baton, pool);
 }
 
 /* --- End machinery for svn_fs_try_process_file_content() ---  */
 
 
 /* --- Machinery for svn_fs_apply_textdelta() ---  */
@@ -3668,7 +3668,7 @@ static root_vtable_t root_vtable = {
   fs_file_length,
   fs_file_checksum,
   fs_file_contents,
-  fs_try_process_file_content,
+  fs_try_process_file_contents,
   fs_make_file,
   fs_apply_textdelta,
   fs_apply_text,
@@ -2261,24 +2261,24 @@ fs_file_contents(svn_stream_t **contents
 }
 
-/* --- End machinery for svn_fs_try_process_file_content() ---  */
+/* --- End machinery for svn_fs_try_process_file_contents() ---  */
 
 

Modified: subversion/branches/10Gb/subversion/libsvn_repos/reporter.c
URL: http://svn.apache.org/viewvc/subversion/branches/10Gb/subversion/libsvn_repos/reporter.c?rev=1388211&r1=1388210&r2=1388211&view=diff
==============================================================================
--- subversion/branches/10Gb/subversion/libsvn_repos/reporter.c (original)
+++ subversion/branches/10Gb/subversion/libsvn_repos/reporter.c Thu Sep 20 20:50:39 2012
@@ -609,7 +609,7 @@ typedef struct zero_copy_baton_t
   svn_boolean_t zero_copy_succeeded;
 } zero_copy_baton_t;
 
 /* Implement svn_fs_process_content_func_t.  If LEN is smaller than the
  * limit given in *BATON, send the CONTENTS as an delta windows to the
  * handler given in BATON and set the ZERO_COPY_SUCCEEDED flag in that
  * BATON.  Otherwise, reset it to FALSE.
@@ -700,10 +700,10 @@ delta_files(report_baton_t *b, void *fil
             {
               zero_copy_baton_t baton = {b->zero_copy_limit, dbaton, FALSE};
               svn_boolean_t called = FALSE;
-              SVN_ERR(svn_fs_try_process_file_content(&called,
-                                                      b->t_root, t_path,
-                                                      send_zero_copy_delta,
-                                                      &baton, pool));
+              SVN_ERR(svn_fs_try_process_file_contents(&called,
+                                                       b->t_root, t_path,
+                                                       send_zero_copy_delta,
+                                                       &baton, pool));
 
               /* data has been available and small enough,
                  i.e. been processed? */
@@ -609,7 +609,7 @@ typedef struct zero_copy_baton_t
 } zero_copy_baton_t;
 
-/* Implement svn_fs_process_content_func_t.  If LEN is smaller than the
+/* Implement svn_fs_process_contents_func_t.  If LEN is smaller than the
  * limit given in *BATON, send the CONTENTS as an delta windows to the
  * handler given in BATON and set the ZERO_COPY_SUCCEEDED flag in that